"""aioskybellgen constants."""

from enum import Enum


class HTTPMethod(Enum):
    """HTTPMethod Enum."""

    DELETE = "DELETE"
    GET = "GET"
    PATCH = "PATCH"
    POST = "POST"
    PUT = "PUT"


CACHE_PATH = "./skybell.pickle"

# URLS
BASE_API_DOMAIN = "https://api.skybell.network"
BASE_AUTH_DOMAIN = "https://api.skybell.network"

BASE_URL = "/api/v5"
BASE_API_URL = BASE_API_DOMAIN + BASE_URL

LOGIN_URL = BASE_AUTH_DOMAIN + BASE_URL + "/login/"
LOGOUT_URL = BASE_AUTH_DOMAIN + BASE_URL + "/logout/"
REFRESH_TOKEN_URL = BASE_AUTH_DOMAIN + BASE_URL + "/token/"

USER_URL = BASE_API_URL + "/user/"

DEVICES_URL = BASE_API_URL + "/devices/"
DEVICE_URL = DEVICES_URL + "$DEVID$/"

DEVICE_SNAPSHOT_URL = DEVICE_URL + "snapshot/"
DEVICE_SETTINGS_URL = DEVICE_URL + "settings/"

ACTIVITIES_URL = BASE_API_URL + "/activity"
ACTIVITY_URL = ACTIVITIES_URL + "/$ACTID$"
ACTIVITY_VIDEO_URL = BASE_API_URL
DEVICE_ACTIVITIES_URL = ACTIVITIES_URL + "?device_id=$DEVID$"
VIDEO_STREAM_PATH = "videostream/"
DEVICE_LIVESTREAM_URL = DEVICE_URL + VIDEO_STREAM_PATH
REBOOT_PATH = "reboot/"
DEVICE_REBOOT_URL = DEVICE_URL + REBOOT_PATH

# GENERAL
RESPONSE_DATA = "data"
RESPONSE_ROWS = "rows"
RESPONSE_MESSAGE = "message"
RESPONSE_ERROR = "error"
STATUS_UP = "Up"
STATUS_DOWN = "Down"

# User
USER_ID = "account_id"
FIRST_NAME = "fname"
LAST_NAME = "lname"

# Authentication and REQUEDT HEADER
AUTHENTICATION_RESULT = "AuthenticationResult"
ACCESS_TOKEN = "AccessToken"
ID_TOKEN = "IdToken"
TOKEN_TYPE = "TokenType"
TOKEN_EXPIRATION = "ExpiresIn"
REFRESH_TOKEN = "RefreshToken"
REFRESH_TOKEN_BODY = "refresh_token"
TOKEN_REFRESHED = "Refreshed"
APP_VERSION = "1.238.1"
EXPIRATION_SLACK = 300
REFRESH_CYCLE = 30
EXPIRATION_DATE = "ExpirationDate"
LIVESTREAM_FORCE_BODY = "force"

# DEVICE
SHARED = "shared"
SHARED_READ_ONLY = "shared_read_only"
DEVICE_ID = "device_id"
NAME = "name"
ACCOUNT_ID = "account_id"
LAST_CONNECTED = "last_connected"
LAST_DISCONNECTED = "last_disconnected"
CREATED_AT = "created_at"
UPDATED_AT = "updated_at"

# DEVICE INFO
DEVICE_SETTINGS = "device_settings"
MAC_ADDRESS = "MAC_address"
MODEL_REV = "model_rev"
SERIAL_NUM = "serial_number"
FIRMWARE_VERSION = "firmware_version"
WIFI_ESSID = "ESSID"

# DEVICE TELEMETRY
DEVICE_TELEMETRY = "telemetry"
DEVICE_LAST_SEEN = "last_seen"
WIFI_LINK_QUALITY = "link_quality"
WIFI_SIGNAL_LEVEL = "signal_level"
WIFI_SSID = "essid"

# DEVICE SETTINGS
SETTINGS = "settings"
DEVICE_NAME = "device_name"  # Used for NAME in settings
BUTTON_PRESSED = "button_pressed"

# NORMAL LED SETTINGS
LED_CONTROL = "led_control"
LED_COLOR = "led_color"

# AUDIO SETTUBGS
INDOOR_CHIME = "indoor_chime"
INDOOR_DIGITAL_CHIME = "digital_chime"
OUTDOOR_CHIME = "outdoor_chime"
OUTDOOR_CHIME_VOLUME = "outdoor_chime_volume"
SPEAKER_VOLUME = "speaker_volume"

# MOTION SETTiNGS
MOTION_DETECTION = "motion_detection"  # Notification for motion
DEBUG_MOTION_DETECTION = "debug_motion_detect"
MOTION_SENSITIVITY = "motion_sensitivity"  # Any Motion Detection
MOTION_HMBD_SENSITIVITY = "hmbd_sensitivity"  # Human Motion Body Detection
MOTION_FD_SENSITIVITY = "fd_sensitivity"  # Face Detection
MOTION_PIR_SENSITIVITY = "pir_sensitivity"  # PIR

# BASIC MOTION SETTINGS
BASIC_MOTION = "basic_motion"
BASIC_MOTION_NOTIFY = "motion_notify"
BASIC_MOTION_RECORD = "motion_record"
BASIC_MOTION_FD_NOTIFY = "fd_notify"
BASIC_MOTION_FD_RECORD = "fd_record"
BASIC_MOTION_HBD_NOTIFY = "hbd_notify"
BASIC_MOTION_HBD_RECORD = "hbd_record"

# IMAGE SETTINGS
IMAGE_QUALITY = "image_quality"

# LOCATION SETTINGS
TIMEZONE_INFO = "time_zone_info"
LOCATION_LAT = "mapLat"
LOCATION_LON = "mapLong"
LOCATION_PLACE = "place"

# DEVICE ACTIVITIES
ACTIVITY = "activity"
ACTIVITY_ID = "activity_id"
EVENT_TYPE = "event_type"
EVENT_TIME = "event_time"
IMAGE = "image"
VIDEO_URL = "video_url"
VIDEO_READY = "video_ready"
DOWNLOAD_URL = "download_url"
DOORBELL_ACTIVITY = "doorbell"
MOTION_ACTIVITY = "motion"
LIVESTREAM_ACTIVITY = "lstream"

# DEVUCE IMAGE SNAPSHOT
SNAPSHOT = "avatar"
PREVIEW_CREATED_AT = "date_time"
PREVIEW_IMAGE = "preview"

# SETTINGS VALUES
FULL_UPDATE_REQUIRED = [
    DEVICE_NAME,
    BASIC_MOTION,
    TIMEZONE_INFO,
]
GRANULAR_PCT_SETTINGS = [
    MOTION_SENSITIVITY,
    MOTION_PIR_SENSITIVITY,
]
DETAIL_SENSITIVITY_SETTINGS = {
    MOTION_HMBD_SENSITIVITY,
    MOTION_FD_SENSITIVITY,
}
USE_MOTION_SENSITIVITY = 4294967295
SENSITIVITY_MIN = 0
SENSITIVITY_MAX = 1000

MOTION_FIELDS = [
    MOTION_SENSITIVITY,
    MOTION_PIR_SENSITIVITY,
    MOTION_HMBD_SENSITIVITY,
    MOTION_FD_SENSITIVITY,
    DEBUG_MOTION_DETECTION,
    BASIC_MOTION,
]

BASIC_MOTION_FIELDS = [
    BASIC_MOTION_NOTIFY,
    BASIC_MOTION_RECORD,
    BASIC_MOTION_FD_NOTIFY,
    BASIC_MOTION_FD_RECORD,
    BASIC_MOTION_HBD_NOTIFY,
    BASIC_MOTION_HBD_RECORD,
]

TIME_ZONE_FIELDS = [
    LOCATION_LAT,
    LOCATION_LON,
    LOCATION_PLACE,
]

LOCATION_COORD_FIELDS = [
    LOCATION_LAT,
    LOCATION_LON,
]

BOOL_SETTINGS = [
    INDOOR_CHIME,
    INDOOR_DIGITAL_CHIME,
    OUTDOOR_CHIME,
    MOTION_DETECTION,
    DEBUG_MOTION_DETECTION,
    BUTTON_PRESSED,
]

# OUTDOOR CHIME FOR DOORBELLS
OUTDOOR_CHIME_LOW = 0
OUTDOOR_CHIME_MEDIUM = 1
OUTDOOR_CHIME_HIGH = 2

OUTDOOR_CHIME_VALUES = [
    OUTDOOR_CHIME_LOW,
    OUTDOOR_CHIME_MEDIUM,
    OUTDOOR_CHIME_HIGH,
]

# SPEAKER VOLUME
SPEAKER_VOLUME_LOW = 0
SPEAKER_VOLUME_MEDIUM = 1
SPEAKER_VOLUME_HIGH = 2

SPEAKER_VOLUME_VALUES = [
    SPEAKER_VOLUME_LOW,
    SPEAKER_VOLUME_MEDIUM,
    SPEAKER_VOLUME_HIGH,
]

NORMAL_LED_CONTROL = "Normal"
NORMAL_LED = "normal_led"
DEFAULT_NORMAL_LED_COLOR = "#00ff00"  # Green

IMAGE_QUALITY_LOW = 0
IMAGE_QUALITY_MEDIUM = 1
IMAGE_QUALITY_HIGH = 2
IMAGE_QUALITY_HIGHEST = 3
IMAGE_QUALITY_VALUES = [
    IMAGE_QUALITY_LOW,
    IMAGE_QUALITY_MEDIUM,
    IMAGE_QUALITY_HIGH,
    IMAGE_QUALITY_HIGHEST,
]

ACL_EXCLUSIONS = [
    BUTTON_PRESSED,
    MOTION_DETECTION,
]
